package whatsapp

import (
	"context"

	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"

	"github.com/suyuan32/simple-admin-common/utils/pointy"
	"github.com/zeromicro/go-zero/core/logx"
)

type GetWhatsappByIdLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetWhatsappByIdLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetWhatsappByIdLogic {
	return &GetWhatsappByIdLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetWhatsappByIdLogic) GetWhatsappById(req *types.IDReq) (*types.WhatsappInfoResp, error) {
	data, err := l.svcCtx.DB.Whatsapp.Get(l.ctx, req.Id)
	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	return &types.WhatsappInfoResp{
		BaseDataInfo: types.BaseDataInfo{
			Code: 0,
			Msg:  errormsg.Success,
		},
		Data: types.WhatsappInfo{
			BaseIDInfo: types.BaseIDInfo{
				Id:        &data.ID,
				CreatedAt: pointy.GetPointer(data.CreatedAt.UnixMilli()),
				UpdatedAt: pointy.GetPointer(data.UpdatedAt.UnixMilli()),
			},
			Status:         &data.Status,
			Ak:             &data.Ak,
			Sk:             &data.Sk,
			Callback:       &data.Callback,
			Account:        &data.Account,
			Nickname:       &data.Nickname,
			Phone:          &data.Phone,
			OrganizationId: &data.OrganizationID,
			AgentId:        &data.AgentID,
			ApiBase:        &data.APIBase,
			ApiKey:         &data.APIKey,
		},
	}, nil
}
