package whatsapp

import (
	"context"

	"wechat-api/ent/predicate"
	"wechat-api/ent/whatsapp"
	"wechat-api/internal/svc"
	"wechat-api/internal/types"
	"wechat-api/internal/utils/dberrorhandler"

	"github.com/suyuan32/simple-admin-common/msg/errormsg"

	"github.com/suyuan32/simple-admin-common/utils/pointy"
	"github.com/zeromicro/go-zero/core/logx"
)

type GetWhatsappListLogic struct {
	ctx    context.Context
	svcCtx *svc.ServiceContext
	logx.Logger
}

func NewGetWhatsappListLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetWhatsappListLogic {
	return &GetWhatsappListLogic{
		ctx:    ctx,
		svcCtx: svcCtx,
		Logger: logx.WithContext(ctx),
	}
}

func (l *GetWhatsappListLogic) GetWhatsappList(req *types.WhatsappListReq) (*types.WhatsappListResp, error) {
	var predicates []predicate.Whatsapp
	if req.Ak != nil {
		predicates = append(predicates, whatsapp.AkContains(*req.Ak))
	}
	if req.Sk != nil {
		predicates = append(predicates, whatsapp.SkContains(*req.Sk))
	}
	if req.Callback != nil {
		predicates = append(predicates, whatsapp.CallbackContains(*req.Callback))
	}
	data, err := l.svcCtx.DB.Whatsapp.Query().Where(predicates...).Page(l.ctx, req.Page, req.PageSize)

	if err != nil {
		return nil, dberrorhandler.DefaultEntError(l.Logger, err, req)
	}

	resp := &types.WhatsappListResp{}
	resp.Msg = errormsg.Success
	resp.Data.Total = data.PageDetails.Total

	for _, v := range data.List {
		resp.Data.Data = append(resp.Data.Data,
			types.WhatsappInfo{
				BaseIDInfo: types.BaseIDInfo{
					Id:        &v.ID,
					CreatedAt: pointy.GetPointer(v.CreatedAt.UnixMilli()),
					UpdatedAt: pointy.GetPointer(v.UpdatedAt.UnixMilli()),
				},
				Status:         &v.Status,
				Ak:             &v.Ak,
				Sk:             &v.Sk,
				Callback:       &v.Callback,
				Account:        &v.Account,
				Nickname:       &v.Nickname,
				Phone:          &v.Phone,
				OrganizationId: &v.OrganizationID,
				AgentId:        &v.AgentID,
				ApiBase:        &v.APIBase,
				ApiKey:         &v.APIKey,
			})
	}

	return resp, nil
}
